@@ -116,7 +116,7 @@ class ConsoleReporter(ReporterInterface):
             kwargs.update(green=True)
         else:
             kwargs.update(red=True)
-            msg += " {0} successful, {1} skipped, {2} failures, {2} errors.".format(
+            msg += " {0} successful, {1} skipped, {2} failures, {3} errors.".format(
                 session.results.get_num_successful(), session.results.get_num_skipped(),
                 session.results.get_num_failures(), session.results.get_num_errors())
 
@@ -155,11 +155,11 @@ class ConsoleReporter(ReporterInterface):
 
             for error_iteration, error in iteration(errors):
                 error_number += 1
-                self._report_error_location(result, error_number, total_num_errors, marker)
+                self._report_error_location(result, error_number, total_num_errors, marker, error)
                 self._report_error(result, error, marker)
 
-    def _report_error_location(self, result, object_index, total_num_errors, marker):
-        self._terminal.sep("_", self._get_location(result))
+    def _report_error_location(self, result, object_index, total_num_errors, marker, error):
+        self._terminal.sep("_", '{0}: {1}'.format(error.time, self._get_location(result)))
         if self._verobsity_allows(VERBOSITIES.INFO) and result.test_metadata:
             location = "{3}:{0}{1}/{2}".format(
                 marker, object_index, total_num_errors, result.test_metadata.id)
